==> json-schema-for-humans-0.34.1.tar.gz: json-schema-for-humans-0.34.1/docs/examples/examples_md_nested_with_badges/complex_const.md <==
# Schema Docs

- [1. Property `root > oneOf > 1st constant`](#oneOf_i0)
- [2. Property `root > oneOf > 2nd constant`](#oneOf_i1)

| Type                      | `combining`                                                                                                         |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

<blockquote>

| One of(Option)            |
| ------------------------- |
| [1st constant](#oneOf_i0) |
| [2nd constant](#oneOf_i1) |
|                           |

<blockquote>

## <a name="oneOf_i0"></a>1. Property `root > oneOf > 1st constant`

**Title:** 1st constant

| Type                      | `const`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

Specific value: `[
    1,
    2
]`

</blockquote>
<blockquote>

## <a name="oneOf_i1"></a>2. Property `root > oneOf > 2nd constant`

**Title:** 2nd constant

| Type                      | `const`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

Specific value: `{
    "a_key": "a_value",
    "another_key": "another_value"
}`

</blockquote>

</blockquote>

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | N/A                |
|                      |                    |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.4.tar.gz: json-schema-for-humans-0.34.4/docs/examples/examples_md_nested_with_badges/complex_const.md <==
# Schema Docs

- [1. Property `root > oneOf > 1st constant`](#oneOf_i0)
- [2. Property `root > oneOf > 2nd constant`](#oneOf_i1)
- [3. Property `root > oneOf > 0`](#oneOf_i2)

| Type                      | `combining`                                                                                                         |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

<blockquote>

| One of(Option)            |
| ------------------------- |
| [1st constant](#oneOf_i0) |
| [2nd constant](#oneOf_i1) |
| [0](#oneOf_i2)            |
|                           |

<blockquote>

## <a name="oneOf_i0"></a>1. Property `root > oneOf > 1st constant`

**Title:** 1st constant

| Type                      | `const`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

Specific value: `[
    1,
    2
]`

</blockquote>
<blockquote>

## <a name="oneOf_i1"></a>2. Property `root > oneOf > 2nd constant`

**Title:** 2nd constant

| Type                      | `const`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

Specific value: `{
    "a_key": "a_value",
    "another_key": "another_value"
}`

</blockquote>
<blockquote>

## <a name="oneOf_i2"></a>3. Property `root > oneOf > 0`

**Title:** 0

| Type                      | `const`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

Specific value: `0`

</blockquote>

</blockquote>

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | N/A                |
|                      |                    |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
